import CipBreadcrumb from '@cip/components/main/cip-main-breadcrumb'
import './index.less'
import { computed } from 'vue'
import BackButton from '../widgets/back-button'
import { useMain } from '@cip/hooks/use-main'
import { useCipConfig } from '@cip/components/hooks/use-cip-config'
export default {
  name: 'CipPageLayoutHandle',
  props: {
    loading: Boolean,
    hideHeader: { type: Boolean, default: undefined },
    hideHandler: { type: Boolean, default: undefined }
  },
  setup (props, { slots }) {
    const { closeTab } = useMain()
    const cipConfig = useCipConfig()
    const usingHideHeader = computed(() => {
      if (props.hideHeader !== undefined) {
        return props.hideHeader
      } else {
        return cipConfig.layout.hideHeader === true
      }
    })
    const usingHideHandler = computed(() => {
      if (props.hideHandler !== undefined) {
        return props.hideHandler
      } else {
        return cipConfig.layout.hideHandler === true
      }
    })
    return () => <div class={'cip-page-layout-handle'} v-loading={props.loading}>
      {!usingHideHeader.value && <div class={'cip-page-layout-handle__breadcrumb'}>
        <BackButton style={'margin-left: 16px'} onClick={() => closeTab()}/>
        <CipBreadcrumb style={'padding-left: 12px'} />
      </div>}
      <div class={'cip-page-layout-handle__main'}>
        {slots.default?.()}
      </div>
      <template>

      </template>
      { !usingHideHandler.value && <div class={'cip-page-layout-handle__handler'} >
        {slots.handler?.() || slots.handle?.()}
      </div>}
    </div>
  }
}
